@@ -2,7 +2,8 @@ SinglefPrior <-
 function(nsim,alpha,lambdamu,lambdasd){
 	    p <- rdirichlet(n=nsim,alpha=alpha)
 	    lambda <- rnorm(nsim,mean=lambdamu,sd=lambdasd)
-	    lgts <- baselogit(p)$baselogit
+	    lgts <- apply(p, 1, function(p) {baselogit(p)$baselogit})
+            if (is.matrix(lgts)) lgts <- t(lgts)
 	    pmin <- apply(p,1,min)
 	    fmin <- -pmin/(1-pmin)
 	    f <- (exp(lambda)+fmin)/(exp(lambda)+1)
